@@ -84,4 +84,10 @@ public class AccountMto {
 
     String personalName;
 
+    boolean pop3Account;
+
+    public boolean isPrimaryAccount() {
+        return "0".equals(id);
+    }
+
 }
